@@ -120,7 +120,11 @@ def getFeeSheet(text: str):
 
 def getCharges(text: str):
 	# get all charges matches
-	c = re.findall(r'(\d{3}\s{1}.{1,100}?.{3}-.{3}-.{3}.{1,100})', str(text), re.MULTILINE)
+	ch = re.findall(r'(\d{3}\s{1}.{1,100}?.{3}-.{3}-.{3}.{1,100})', str(text), re.MULTILINE)
+	c = []
+	for ch in c:
+		charge = ch.replace("SentencesSentence 1","").strip()
+		c += [charge]
 	cind = range(0, len(c))
 	charges = pd.DataFrame({'Charges': c},index=cind)
 	charges['Charges'] = charges['Charges'].map(lambda x: x.strip().replace("\n",""))
