@@ -90,11 +90,11 @@ def log_complete(tostr=""):
 	global start_time
 	completion_time = time.time()
 	elapsed = completion_time - start_time
-	if mode == "archive-from-directory":
+	if m == "archive-from-directory":
 		pmode = "Creating full text archive from PDF directory..."
-	if mode == "tables-from-archive":
+	if m == "tables-from-archive":
 		pmode = "Processing archive into detailed case information table..."
-	if mode == "tables-from-directory":
+	if m == "tables-from-directory":
 		pmode = "Collecting detailed case information from directory contents..."
 	print(tostr)
 	print(f'''
